@@ -212,7 +212,7 @@ class AB_Base:
                 self.logger.debug("Doing Complex Search: {}".format(potential))
                 all_passed = True
                 for k, v in self.kwargs["search_complex"].items():
-                    compare_value = potential.get("k", None)
+                    compare_value = potential.get(k, None)
 
                     if isinstance(compare_value, list):
                         self.logger.error("List Values can't be compared at this time.")
